@@ -1,17 +1,11 @@
 # -*- coding:utf-8 -*-
 
-from typing import Callable, Dict, Iterable, List, Optional, Tuple
-import sys
-import subprocess
-import asyncio
-import logging
+from typing import Callable, Dict, Iterable, List, Optional, Tuple, ByteString, Union
+import sys, subprocess, asyncio
 from math import sqrt
 from collections import Counter
 
 
-Log = logging.getLogger(__name__)
-
-
 def traceback_info(extra_msg: str = "null") -> str:
     """Get traceback infomation.
 
@@ -35,56 +29,41 @@ def traceback_info(extra_msg: str = "null") -> str:
     )
 
 
-def run_cmd(*args, cwd: Optional[str] = None) -> bool:
-    """Run system command.
+def exec_cmd(
+    *args, cwd: Optional[str] = None, reply: bool = True, decoding: bool = True
+) -> Tuple[Union[str, ByteString, None], ...]:
+    """Run system shell command.
 
-    Returns:
-        (bool): Whether run successful.
-
-    Docs test
-        >>> run_cmd('pwd')
-        True
-        >>> run_cmd('which', 'python')
-        True
+    Args:
+        reply (bool): whether return execute result. Default is True.
+        decoding (bool): whether decode the return. Default is True.
     """
+    _stderr: Optional[int] = subprocess.PIPE if reply else None
+    _stdout: Optional[int] = subprocess.PIPE if reply else None
 
-    try:
-        # ? In python2, `subprocess` not support `with` sentence.
-        proc = subprocess.Popen(" ".join(args), shell=True, cwd=cwd)
-        proc.wait()
-    except Exception:
-        Log.error(traceback_info())
-        return False
-    else:
-        return True
-
-
-def exec_cmd(*args, cwd: Optional[str] = None) -> Tuple[str, str]:
-    """Run system command and get result.
-
-    Returns:
-        (str, str): Error string and result string.
-    """
+    _err: Union[str, ByteString, None] = None
+    _rlt: Union[str, ByteString, None] = None
 
     try:
         # Take over the input stream and get the return information.
         with subprocess.Popen(
-            " ".join(args),
-            stderr=subprocess.PIPE,
-            stdout=subprocess.PIPE,
-            shell=True,
-            cwd=cwd,
+            " ".join(args), stderr=_stderr, stdout=_stdout, shell=True, cwd=cwd
         ) as proc:
-
-            output = proc.communicate()
-            # Get normal output and error output.
-            res = output[0].decode()
-            err = output[1].decode()
-    except Exception as e:
-        Log.error(traceback_info())
-        return str(e), ""
+            outres, errres = proc.communicate()
+    except FileNotFoundError as e:
+        _err = str(e).encode()
     else:
-        return err, res
+        _err, _rlt = errres, outres
+
+    if not decoding:
+        return _err, _rlt
+
+    # decode
+    if _err is not None:
+        _err = _err.decode()
+    if _rlt is not None:
+        _rlt = _rlt.decode()
+    return _err, _rlt
 
 
 async def async_run_cmd(
@@ -206,17 +185,6 @@ def similar_command(command: str, all_commands: Iterable) -> str:
     return min_frequency_command
 
 
-def get_current_shell() -> str:
-    """Gets the currently used shell.
-
-    Returns:
-            (str): Current shell string.
-    """
-    _, resp = exec_cmd("echo $SHELL")
-    current_shell = resp.split("/")[-1].strip() if resp else ""
-    return current_shell.lower()
-
-
 # Mark the type corresponding to the file suffix.
 # abcdefg hijklmn opq rst uvw xyz
 SUFFIX_TYPE: Dict[str, str] = {
