@@ -8,7 +8,7 @@ from .common.utils import confirm, traceback_info
 from .common.singleton import Singleton
 from .render.style import Color
 
-Log = logging.getLogger(__name__)
+Logger = logging.getLogger(__name__)
 
 CONF_ERROR = "==error=="
 
@@ -19,7 +19,7 @@ class ConfigError(Exception):
     pass
 
 
-class Config(object, metaclass=Singleton):
+class Config(metaclass=Singleton):
     """PIGIT configuration class."""
 
     CONFIG_TEMPLATE: str = textwrap.dedent(
@@ -56,9 +56,6 @@ class Config(object, metaclass=Singleton):
         # When the command line width is not enough, the `simple ` format is forced.
         counter_format={counter_format}
 
-        # (int) Timeout for getting `.gitignore` template from network.
-        gitignore_generator_timeout={gitignore_generator_timeout}
-
         # Git local config print format. Supported: [table, normal]
         git_config_format={git_config_format}
 
@@ -86,7 +83,6 @@ class Config(object, metaclass=Singleton):
         "counter_show_invalid",
         "counter_show_icon",
         "counter_format",
-        "gitignore_generator_timeout",
         "git_config_format",
         "repo_info_include",
         "repo_auto_append",
@@ -94,9 +90,9 @@ class Config(object, metaclass=Singleton):
         "log_output",
     ]
 
-    #########################
+    # ======================
     # config default values.
-    #########################
+    # ======================
 
     # cmd processor conf
     cmd_show_original: bool = True
@@ -112,9 +108,6 @@ class Config(object, metaclass=Singleton):
     counter_format: str = "table"  # table, simple
     _supported_result_format: List = ["table", "simple"]
 
-    # ignore file conf
-    gitignore_generator_timeout: int = 60
-
     # info conf
     git_config_format: str = "table"
     _supported_git_config_format: List = ["normal", "table"]
@@ -134,8 +127,6 @@ class Config(object, metaclass=Singleton):
     def __init__(
         self, path: str, version: str = "unknown", auto_load: bool = True
     ) -> None:
-        super(Config, self).__init__()
-
         self.config_file_path: str = path
         self.current_version: str = version
         self.conf: Dict = {}
@@ -143,7 +134,7 @@ class Config(object, metaclass=Singleton):
         if auto_load:
             self.load_config()
 
-    def output_warnings(self):
+    def output_warnings(self) -> None:
         """Output config warning info and return self object.
 
         Returns:
@@ -160,21 +151,39 @@ class Config(object, metaclass=Singleton):
 
         return self
 
-    def load_config(self) -> None:
-        try:
-            self.read_config()
-        except Exception as e:
-            Log.error(traceback_info())
-            self.warnings.append("Can not load the config file.")
-
-        self.parse_conf()
-
-        # setting config.
-        for key in self._keys:
-            if key in self.conf.keys() and self.conf[key] != CONF_ERROR:
-                setattr(self, key, self.conf[key])
+    def check_and_set_value(self, key: str, value: str, new_config: Dict) -> None:
+        if key not in self._keys:
+            self.warnings.append(f"'{key}' is not be supported!")
+        elif type(getattr(self, key)) == int:
+            try:
+                new_config[key] = int(value)
+            except ValueError:
+                self.warnings.append(f'Config key "{key}" should be an integer!')
+        elif type(getattr(self, key)) == float:
+            try:
+                new_config[key] = float(value)
+            except ValueError:
+                self.warnings.append(f'Config key "{key}" should be a float!')
+        elif type(getattr(self, key)) == bool:
+            try:
+                # True values are y, yes, t, true, on and 1;
+                # false values are n, no, f, false, off and 0.
+                # Raises ValueError if val is anything else.
+                new_config[key] = bool(strtobool(value))
+            except ValueError:
+                self.warnings.append(f'Config key "{key}" can only be True or False!')
+        elif type(getattr(self, key)) == str:
+            if "color" in key and not Color.is_color(value):
+                self.warnings.append(
+                    f'Config key "{key}" should be RGB string, like: "#FF0000".'
+                )
             else:
-                self.conf[key] = getattr(self, key)
+                new_config[key] = value
+        elif type(getattr(self, key)) == list:
+            if re.match(r"^\[[\w\s0-9\'\"_]+,?([\s\w0-9\'\"_]+,?)*\]$", value):
+                new_config[key] = eval(value)
+            else:
+                self.warnings.append(f'Config key "{key}" not support `{value}`.')
 
     def read_config(self) -> None:
         new_config = self.conf
@@ -192,52 +201,18 @@ class Config(object, metaclass=Singleton):
                 if "=" not in line:
                     # invalid line.
                     continue
-                key, line = line.split("=", maxsplit=1)
+
+                # remove line comment.
+                if line_comment_idx := line.find("#") > 0:
+                    line = line[:line_comment_idx]
 
                 # processing.
-                key = key.strip()
-                line = line.strip().strip('"')
+                key_string, value_string = line.split("=", maxsplit=1)
+                key_string = key_string.strip()
+                value_string = value_string.strip().strip('"')
 
                 # checking.
-                if key not in self._keys:
-                    self.warnings.append(f"'{key}' is not be supported!")
-                    continue
-                elif type(getattr(self, key)) == int:
-                    try:
-                        new_config[key] = int(line)
-                    except ValueError:
-                        self.warnings.append(
-                            f'Config key "{key}" should be an integer!'
-                        )
-                elif type(getattr(self, key)) == float:
-                    try:
-                        new_config[key] = float(line)
-                    except ValueError:
-                        self.warnings.append(f'Config key "{key}" should be a float!')
-                elif type(getattr(self, key)) == bool:
-                    try:
-                        # True values are y, yes, t, true, on and 1;
-                        # false values are n, no, f, false, off and 0.
-                        # Raises ValueError if val is anything else.
-                        new_config[key] = bool(strtobool(line))
-                    except ValueError:
-                        self.warnings.append(
-                            f'Config key "{key}" can only be True or False!'
-                        )
-                elif type(getattr(self, key)) == str:
-                    if "color" in key and not Color.is_color(line):
-                        self.warnings.append(
-                            f'Config key "{key}" should be RGB string, like: "#FF0000".'
-                        )
-                        continue
-                    new_config[key] = str(line)
-                elif type(getattr(self, key)) == list:
-                    if re.match(r"^\[[\w\s0-9\'\"_]+,?([\s\w0-9\'\"_]+,?)*\]$", line):
-                        new_config[key] = eval(line)
-                    else:
-                        self.warnings.append(
-                            f'Config key "{key}" not support `{line}`.'
-                        )
+                self.check_and_set_value(key_string, value_string, new_config)
 
     def parse_conf(self) -> None:
         new_config = self.conf
@@ -283,6 +258,24 @@ class Config(object, metaclass=Singleton):
                 "You'd better recreate it."
             )
 
+    def load_config(self) -> None:
+        try:
+            self.read_config()
+        except Exception:
+            Logger.error(traceback_info())
+            self.warnings.append(
+                f"Can not load the config file. Path: {self.config_file_path}"
+            )
+
+        self.parse_conf()
+
+        # setting config.
+        for key in self._keys:
+            if key in self.conf.keys() and self.conf[key] != CONF_ERROR:
+                setattr(self, key, self.conf[key])
+            else:
+                self.conf[key] = getattr(self, key)
+
     def create_config_template(self) -> None:
         parent_dir = os.path.dirname(self.config_file_path)
         if not os.path.isdir(parent_dir):
@@ -297,15 +290,15 @@ class Config(object, metaclass=Singleton):
         self.load_config()
         self.conf["version"] = self.current_version
 
-        # Write config. Will save before custom setting.
+        # Write config with already exist custom settings.
         try:
             with open(
                 self.config_file_path,
                 "w" if os.path.isfile(self.config_file_path) else "x",
             ) as f:
                 f.write(self.CONFIG_TEMPLATE.format(**self.conf))
-        except Exception as e:
-            Log.error(traceback_info())
+        except Exception:
+            Logger.error(traceback_info())
             print("Fail to create config.")
         else:
             print("Successful.")
